==> openGion_dev_5.9.1.0.zip: opengion/uap/webapps/ge/db/oracle/sql/install/01_TABLE/GE62S.sql <==
/****************************************************************************/
/* GE62 ( 伝送定義ﾏｽﾀ )                                                     */
/*                                                                          */
/* Created : 2014/12/16 09:05:42                                            */
/****************************************************************************/
CREATE TABLE GE62 (
   SYSTEM_ID    VARCHAR2 (  10 )                    NOT NULL            /*  10 ｼｽﾃﾑID           */
 , KBREAD       VARCHAR2 (  20 )                    NOT NULL            /*  20 読取方法         */
 , READOBJ      VARCHAR2 ( 200 )                    NOT NULL            /*  30 読取対象         */
 , READPRM      VARCHAR2 ( 200 )                                        /*  40 読取ﾊﾟﾗﾒｰﾀｰ      */
 , KBEXEC       VARCHAR2 (  20 )                    NOT NULL            /*  50 実行方法         */
 , EXECDBID     VARCHAR2 ( 100 )                                        /*  60 実行DB接続先ID   */
 , EXECOBJ      VARCHAR2 ( 200 )                    NOT NULL            /*  70 実行対象         */
 , EXECPRM      VARCHAR2 ( 200 )                                        /*  80 実行ﾊﾟﾗﾒｰﾀｰ      */
 , DMN_GRP      VARCHAR2 (  20 )                    NOT NULL            /*  90 ﾃﾞｰﾓﾝｸﾞﾙｰﾌﾟ      */
 , DMN_TIME     NUMBER   (   6 )        DEFAULT 60  NOT NULL            /* 100 ﾃﾞｰﾓﾝ間隔        */
 , ERROR_SENDTO VARCHAR2 ( 200 )                                        /* 110 ｴﾗｰ送信先        */
 , UNIQ         NUMBER   (   9 )        DEFAULT 0   NOT NULL            /* 120 ﾕﾆｰｸｷｰ           */
 , FGJ          VARCHAR2 (   1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ         */
 , DYSET        VARCHAR2 (  14 )                                        /* 820 登録日時         */
 , PGSET        VARCHAR2 (  10 )                                        /* 830 作成PG           */
 , PGPSET       VARCHAR2 (  10 )                                        /* 840 作成親PG         */
 , USRSET       VARCHAR2 (  10 )                                        /* 850 作成社員         */
 , DYUPD        VARCHAR2 (  14 )                                        /* 860 更新日時         */
 , PGUPD        VARCHAR2 (  10 )                                        /* 870 更新PG           */
 , PGPUPD       VARCHAR2 (  10 )                                        /* 880 更新親PG         */
 , USRUPD       VARCHAR2 (  10 )                                        /* 890 更新者           */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K NEXT 16K PCTINCREASE 0 );

CREATE SEQUENCE GE62S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;

CREATE OR REPLACE TRIGGER GE62T00 
  BEFORE INSERT ON GE62
  FOR EACH ROW 
  BEGIN 
    SELECT GE62S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/

==> openGion_dev_5.9.2.0.zip: opengion/uap/webapps/ge/db/oracle/sql/install/01_TABLE/GE62S.sql <==
/****************************************************************************/
/* GE62 ( 伝送定義ﾏｽﾀ )                                                     */
/*                                                                          */
/* Created : 2015/10/28 15:14:26                                            */
/****************************************************************************/
CREATE TABLE GE62 (
   SYSTEM_ID    VARCHAR2 (  10 )                    NOT NULL            /*  10 ｼｽﾃﾑID           */
 , KBREAD       VARCHAR2 (  20 )                    NOT NULL            /*  20 読取方法         */
 , READOBJ      VARCHAR2 ( 200 )                    NOT NULL            /*  30 読取対象         */
 , READPRM      VARCHAR2 ( 200 )                                        /*  40 読取ﾊﾟﾗﾒｰﾀｰ      */
 , KBEXEC       VARCHAR2 (  20 )                    NOT NULL            /*  50 実行方法         */
 , EXECDBID     VARCHAR2 ( 100 )                                        /*  60 実行DB接続先ID   */
 , EXECOBJ      VARCHAR2 ( 200 )                    NOT NULL            /*  70 実行対象         */
 , EXECPRM      VARCHAR2 ( 200 )                                        /*  80 実行ﾊﾟﾗﾒｰﾀｰ      */
 , DMN_GRP      VARCHAR2 (  20 )                    NOT NULL            /*  90 ﾃﾞｰﾓﾝｸﾞﾙｰﾌﾟ      */
 , DMN_TIME     NUMBER   (   6 )        DEFAULT 60  NOT NULL            /* 100 ﾃﾞｰﾓﾝ間隔        */
 , ERROR_SENDTO VARCHAR2 ( 200 )                                        /* 110 ｴﾗｰ送信先        */
 , UNIQ         NUMBER   (   9 )        DEFAULT 0   NOT NULL            /* 120 ﾕﾆｰｸｷｰ           */
 , FGJ          VARCHAR2 (   1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ         */
 , DYSET        VARCHAR2 (  14 )                                        /* 820 登録日時         */
 , PGSET        VARCHAR2 (  10 )                                        /* 830 作成PG           */
 , PGPSET       VARCHAR2 (  10 )                                        /* 840 作成親PG         */
 , USRSET       VARCHAR2 (  10 )                                        /* 850 作成社員         */
 , DYUPD        VARCHAR2 (  14 )                                        /* 860 更新日時         */
 , PGUPD        VARCHAR2 (  10 )                                        /* 870 更新PG           */
 , PGPUPD       VARCHAR2 (  10 )                                        /* 880 更新親PG         */
 , USRUPD       VARCHAR2 (  10 )                                        /* 890 更新者           */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K NEXT 16K );

CREATE SEQUENCE GE62S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;

CREATE OR REPLACE TRIGGER GE62T00 
  BEFORE INSERT ON GE62
  FOR EACH ROW 
  BEGIN 
    SELECT GE62S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/
